@@ -1,7 +1,6 @@
 """Registers functions to be called if an exception or signal occurs."""
 import functools
 import logging
-import os
 import signal
 import traceback
 
@@ -10,6 +9,7 @@ from acme.magic_typing import Any, Callable, Dict, List, Union
 # pylint: enable=unused-import, no-name-in-module
 
 from certbot import errors
+from certbot.compat import os
 
 logger = logging.getLogger(__name__)
 
@@ -73,7 +73,7 @@ class ErrorHandler(object):
     deferred until they finish.
 
     """
-    def __init__(self, func=None, *args, **kwargs):
+    def __init__(self, func, *args, **kwargs):
         self.call_on_regular_exit = False
         self.body_executed = False
         self.funcs = []  # type: List[Callable[[], Any]]
@@ -167,7 +167,6 @@ class ExitHandler(ErrorHandler):
     In addition to cleaning up on all signals, also cleans up on
     regular exit.
     """
-    def __init__(self, func=None, *args, **kwargs):
+    def __init__(self, func, *args, **kwargs):
         ErrorHandler.__init__(self, func, *args, **kwargs)
         self.call_on_regular_exit = True
-
