@@ -19,6 +19,7 @@ from certbot import cli
 from certbot import errors
 from certbot import interfaces
 from certbot.compat import os
+from certbot.compat import filesystem
 from certbot.display import ops
 from certbot.display import util as display_util
 from certbot.plugins import common
@@ -168,19 +169,19 @@ to serve all files under specified web root ({0})."""
             # run as non-root (GH #1795)
             old_umask = os.umask(0o022)
             try:
-                stat_path = os.stat(path)
                 # We ignore the last prefix in the next iteration,
                 # as it does not correspond to a folder path ('/' or 'C:')
                 for prefix in sorted(util.get_prefixes(self.full_roots[name])[:-1], key=len):
                     try:
-                        # This is coupled with the "umask" call above because
+                        # Set owner as parent directory if possible, apply mode for Linux/Windows.
+                        # For Linux, this is coupled with the "umask" call above because
                         # os.mkdir's "mode" parameter may not always work:
                         # https://docs.python.org/3/library/os.html#os.mkdir
-                        os.mkdir(prefix, 0o0755)
+                        filesystem.mkdir(prefix, 0o755)
                         self._created_dirs.append(prefix)
-                        # Set owner as parent directory if possible
                         try:
-                            os.chown(prefix, stat_path.st_uid, stat_path.st_gid)
+                            filesystem.copy_ownership_and_apply_mode(
+                                path, prefix, 0o755, copy_user=True, copy_group=True)
                         except (OSError, AttributeError) as exception:
                             logger.info("Unable to change owner and uid of webroot directory")
                             logger.debug("Error was: %s", exception)
