@@ -33,6 +33,7 @@ from certbot import updater
 from certbot import util
 from certbot.compat import misc
 from certbot.compat import os
+from certbot.compat import filesystem
 from certbot.plugins import disco
 from certbot.plugins import enhancements
 from certbot.plugins import manual
@@ -513,7 +514,7 @@ class MainTest(test_util.ConfigTestCase):  # pylint: disable=too-many-public-met
     def setUp(self):
         super(MainTest, self).setUp()
 
-        os.mkdir(self.config.logs_dir)
+        filesystem.mkdir(self.config.logs_dir)
         self.standard_args = ['--config-dir', self.config.config_dir,
                               '--work-dir', self.config.work_dir,
                               '--logs-dir', self.config.logs_dir, '--text']
@@ -757,6 +758,13 @@ class MainTest(test_util.ConfigTestCase):  # pylint: disable=too-many-public-met
         _, _, _, client = self._call(['config_changes'])
         self.assertEqual(1, client.view_config_changes.call_count)
 
+    @mock.patch('certbot.main.logger.warning')
+    def test_config_changes_deprecation(self, mock_warning):
+        self._call(['config_changes'])
+        self.assertTrue(mock_warning.called)
+        msg = mock_warning.call_args[0][0]
+        self.assertIn("config_changes subcommand has been deprecated", msg)
+
     @mock.patch('certbot.cert_manager.update_live_symlinks')
     def test_update_symlinks(self, mock_cert_manager):
         self._call_no_clientmock(['update_symlinks'])
@@ -1154,7 +1162,7 @@ class MainTest(test_util.ConfigTestCase):  # pylint: disable=too-many-public-met
     def test_renew_verb_empty_config(self):
         rd = os.path.join(self.config.config_dir, 'renewal')
         if not os.path.exists(rd):
-            os.makedirs(rd)
+            filesystem.makedirs(rd)
         with open(os.path.join(rd, 'empty.conf'), 'w'):
             pass  # leave the file empty
         args = ["renew", "--dry-run", "-tvv"]
@@ -1172,7 +1180,7 @@ class MainTest(test_util.ConfigTestCase):  # pylint: disable=too-many-public-met
 
     def _make_dummy_renewal_config(self):
         renewer_configs_dir = os.path.join(self.config.config_dir, 'renewal')
-        os.makedirs(renewer_configs_dir)
+        filesystem.makedirs(renewer_configs_dir)
         with open(os.path.join(renewer_configs_dir, 'test.conf'), 'w') as f:
             f.write("My contents don't matter")
 
